==> haskell-hspec-core-2.10.9-107.6-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-core
version:              2.10.9
visibility:           public
id:                   hspec-core-2.10.9-EPbsf4CX1VNHe1gcsgpM0I
key:                  hspec-core-2.10.9-EPbsf4CX1VNHe1gcsgpM0I
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  4c8df47509a95bc171395630c72b90a9
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-core-2.10.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-core-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.10.9-EPbsf4CX1VNHe1gcsgpM0I
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE array-0.5.4.0
    base-4.16.4.0 call-stack-0.4.0-kYtciisYfe7TdjBJDTvHP
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2
    haskell-lexer-1.1.1-K7I6uqCDpmCAWLRFKaxnTu
    hspec-expectations-0.8.3-53KTMpuZLbD4EdixkL29oj process-1.6.16.0
    quickcheck-io-0.2.0-5urG4IHODupLLGWmmxnDTv
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    setenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY stm-2.5.0.2
    tf-random-0.5-cUtlI4Xks6I7UvfJcEEK3 time-1.11.1.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.10.9-209.5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.10.9
visibility:           public
id:                   hspec-core-2.10.9-JXA91YXBxjG5KLMnkMduaR
key:                  hspec-core-2.10.9-JXA91YXBxjG5KLMnkMduaR
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  36ff5d261acea33664f863cb4aeecee3
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-core-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.10.9-JXA91YXBxjG5KLMnkMduaR
depends:
    HUnit-1.6.2.0-DucYFi7W996LJfea0vxExR
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
    ansi-terminal-1.0.2-CHKNXEXhuZ3EvZtvAUncPO array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-DB4dQQkTPQ5DiL3lPhgRb2
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    haskell-lexer-1.1.1-Hpax8yMtr9r8FzGXIYjm8Z
    hspec-expectations-0.8.3-8SHeV75XzHGAS0nDpIhPfV process-1.6.18.0
    quickcheck-io-0.2.0-KtbH4rjbBsD3YHNjbd2wYa
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj
    setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb stm-2.5.1.0
    tf-random-0.5-LYjCAzso7XMgc4oa8txtH time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
